@@ -7,7 +7,8 @@ from cyberfusion.ClusterSupport._interfaces import (
     sort_lists,
 )
 
-ENDPOINT_MAIL_ACCOUNTS_USAGES = "mail-accounts/usages"
+ENDPOINT_PUBLIC_MAIL_ACCOUNTS_USAGES = "/api/v1/mail-accounts/usages"
+ENDPOINT_INTERNAL_MAIL_ACCOUNTS_USAGES = "/internal/api/v1/mail-accounts/usages"
 
 
 class MailAccountUsage(APIObjectInterface):
@@ -19,6 +20,8 @@ class MailAccountUsage(APIObjectInterface):
         obj: dict,
     ) -> None:
         """Set class attributes from API output."""
+        self.json_body = obj
+
         self.usage = obj["usage"]
         self.mail_account_id = obj["mail_account_id"]
         self.timestamp = obj["timestamp"]
@@ -29,7 +32,7 @@ class MailAccountUsage(APIObjectInterface):
 
     def create(self, *, usage: float, mail_account_id: int) -> None:
         """Create object."""
-        url = f"/api/v1/{ENDPOINT_MAIL_ACCOUNTS_USAGES}"
+        url = ENDPOINT_INTERNAL_MAIL_ACCOUNTS_USAGES
         data = {
             "usage": usage,
             "mail_account_id": mail_account_id,
